@@ -73,6 +73,7 @@
 import codecs
 import datetime
 import hashlib
+import logging
 import os
 import sys
 import StringIO
@@ -131,6 +132,9 @@ RESOURCE_MAP_FORMAT_ID = 'http://www.openarchives.org/ore/terms'
 
 
 def main():
+  logging.basicConfig()
+  logging.getLogger('').setLevel(logging.DEBUG)
+
   # Create a Member Node client that can be used for running commands against
   # a specific Member Node.
   client = d1_client.mnclient.MemberNodeClient(MN_BASE_URL,
